% Matlab script start
clear all; clc
filename='M:\Documents\MASTER THESIS\Working_folder\Inventory.xlsx';
load ('Ecoinvent_2_2_database.mat');
load ('C_large.mat');
% Import of all necessary already established databases: 
% EXIOPOL (A_exiopol), Ecoinvent process matrix (A_gen), Ecoinvent 
% stressor matrix (F_gen), (modified to take into account EXIOPOL stressors too)
% and C_large - a characterization matrix covering both Ecoinvent and Exiobase stressors.  

%% Imports of foreground data 
A_f=xlsread(filename,'A','E8:AC4377'); % A_f contains 
% A_ff (foreground inter-process requirements matrix) and 
% A_nf (matrix of requirements from the foreground to Ecoinvent)
A_f(isnan(A_f))=0; % Making sure all empty fields are 0

y=xlsread(filename,'y','E8:E4377');
y(isnan(y))=0;

H_nf=xlsread(filename,'H_nf','F15:AD272');
H_nf(isnan(H_nf))=0; 

p_f=xlsread(filename,'p_f','E6:E30');
p_f(isnan(p_f))=0; 

Z_nf=xlsread(filename,'Z_nf','F15:AD272');
Z_nf(isnan(Z_nf))=0;

A_bb=A_gen;
A_nn=xlsread('M:\Documents\MASTER THESIS\Working_folder\SIOT_2region_pxp.xlsx','A','F15:JC272');
A_nn(isnan(A_nn))=0;

% Create the A_nf (matrix of requirements from the foreground 
% to EXIOPOL) matrices 

A_nf_adj=A_nn*H_nf*diag(p_f);
A_nf=Z_nf.*A_nf_adj;

F_ff=xlsread(filename,'F_ff','E4:AC2342'); %SF6 losses included into stressors matrix
F_ff(isnan(F_ff))=0;


%% Construct A-matrix
[m n]=size(A_f);
A=zeros(m,m);
A(1:m,1:25)=A_f;%A_ff
A(26:283,26:283)=A_nn;%Exiopol_inventory
A(284:m,284:m)=A_bb;%Ecoinvent_inventory
A(26:283,1:25)=A_nf; 


%% Finding total output
I=eye(size(A));
L=inv(I-A);

x=L*y;


%% Construct F-matrix 
S=xlsread('M:\Documents\MASTER THESIS\Working_folder\SIOT_2region_pxp.xlsx','A','F274:JC999'); %Exiopol stressors matrix
S(isnan(S))=0;
F_large=[S zeros(size(S,1),size(F_gen,2)); zeros(size(F_gen,1),size(S,2)) F_gen]; %Combined stressors matrix
[r t]=size(F_large);
F=[F_ff F_large];
C_ecoinvent=C_large(:,[1:1613]);
C_exiopol=C_large(:,[1615:end]);
C=[C_exiopol C_ecoinvent];
CF=C*F;

%% Emissions and impacts
% Calculates the vector of total impacts generated for a given external demand
d=CF*x;
D_pro=CF*diag(x);
%% Emissions allocated to foreground processes
D_pro_ff=CF*L*diag(y);% Zeroth tier
D_pro_ff_1stT=CF*L*diag(A*y);% First tier
D_str=C*diag(F*x); % contribution of stressors

%% Advanced contribution analysis
I_A_f=eye(25,25);
I_A_nn=eye(size(A_nn));
I_A_bb=eye(size(A_bb));

X_f=inv(I_A_f-A_f(1:25,1:25))*y(1:25,1);

M_nf=A_nf*diag(X_f);
X_nf=inv(I_A_nn)*M_nf;
D_pro_nf=C_exiopol*S*X_nf;

M_bf=A_f(284:end,1:25)*diag(X_f);
X_bf=inv(I_A_bb)*M_bf;
D_pro_bf=C_ecoinvent*F_gen*X_bf;


xlswrite(filename,d,'Results','E2:E19');
xlswrite(filename,D_pro,'Results','C23:FLD40');
xlswrite(filename,D_pro_ff,'Results','C44:FLD61');
xlswrite(filename,D_pro_ff_1stT,'Results','C66:FLD83');




% Matlab script end