% Matlab script start
clear all; clc
filename='M:\Documents\MASTER THESIS\Working_folder\Inventory_analysis_sub_comp.xlsx';
load ('Ecoinvent_2_2_database.mat');
load ('C_large.mat');
% Import of all necessary already established databases: 
% EXIOPOL (A_exiopol), Ecoinvent process matrix (A_gen), Ecoinvent 
% stressor matrix (F_gen), (modified to take into account EXIOPOL stressors too)
% and C_large - a characterization matrix covering both Ecoinvent and Exiobase stressors.  

%% Imports of foreground data 
A_f=xlsread(filename,'A','E8:AC4377'); %A_f contains 
% A_ff (foreground inter-process requirements matrix) and 
% A_nf (matrix of requirements from the foreground to Ecoinvent)
A_f(isnan(A_f))=0; % Making sure all empty fields are 0

y=xlsread(filename,'y','E8:E4377');
y(isnan(y))=0;

H_nf=xlsread(filename,'H_nf','F15:AD272');
H_nf(isnan(H_nf))=0; 

p_f=xlsread(filename,'p_f','E6:E30');
p_f(isnan(p_f))=0; 

Z_nf=xlsread(filename,'Z_nf','F15:AD272');
Z_nf(isnan(Z_nf))=0;

A_bb=A_gen;
A_nn=xlsread('M:\Documents\MASTER THESIS\Working_folder\SIOT_2region_pxp.xlsx','A','F15:JC272');
A_nn(isnan(A_nn))=0;

% Create the A_nf (matrix of requirements from the foreground 
% to EXIOPOL) matrices 

A_nf_adj=A_nn*H_nf*diag(p_f);
A_nf=Z_nf.*A_nf_adj;

%% Construct A-matrix
[m n]=size(A_f);
A=zeros(m,m);
A(1:4370,1:25)=A_f; %A_ff
A(26:283,1:25)=A_nf; 

A(26:m,[1:16 18:m])=0; %zero inputs in physical dataset for IO/LCA share for components
p_f([1:16 18:25],1)=0; %zero inputs in monetary dataset for IO/LCA share for components

A(26:283,26:283)=A_nn; %Exiopol_inventory
A(284:4370,284:4370)=A_bb; %Ecoinvent_inventory

%% Finding total output
I=eye(size(A));
L=inv(I-A);

x=L*y;


%% Construct F-matrix 
S=xlsread('M:\Documents\MASTER THESIS\Working_folder\SIOT_2region_pxp.xlsx','A','F274:JC999'); %Exiopol stressors matrix
S(isnan(S))=0;
F_large=[S zeros(size(S,1),size(F_gen,2)); zeros(size(F_gen,1),size(S,2)) F_gen]; %Combined stressors matrix
[r t]=size(F_large);
F=zeros(r,t+n);
F(1:r,26:4370)=F_large;
C_ecoinvent=C_large(:,[1:1613]);
C_exiopol=C_large(:,[1615:end]);
C=[C_exiopol C_ecoinvent];
CF=C*F;

%% Emissions and impacts
% Calculates the vector of total impacts generated for a given external demand
d=CF*x;
D_pro=CF*diag(x);
%% Emissions allocated to foreground processes
D_pro_ff=CF*L*diag(y);% Zeroth tier

%% Emissions allocated to processes (2nd tier)
D_pro_ff_2=CF*L*diag(A*A*y);% 2nd tier

%% Results_OHL tabs: 2_Found_Inf; 3_Masts_Inf; 4_Insul_Inf; 5_Cond_Inf;
%%6_Activ_Inf; 7_Masts_Oper; 8_Insul_Oper; 9_Cond_Oper; 10_Activ_Oper
%%11_Found_Waste; 12_Masts_Waste; 13_Insul_Waste; 14_Cond_Waste; 15_Activ_Waste
%% Results_GIS tabs: 17_Trafo; 18_CirBr; 19_Bay; 20_CivWor; 21_SitePr;
%%22_OtherEq; 23_OtherWor; 24_EOL; 25_SF6
xlswrite('M:\Documents\MASTER THESIS\Working_folder\Results_GIS.xlsx',d,'17_Trafo','E2:E19'); 
xlswrite('M:\Documents\MASTER THESIS\Working_folder\Results_GIS.xlsx',D_pro,'17_Trafo','C23:FLD40');
xlswrite('M:\Documents\MASTER THESIS\Working_folder\Results_GIS.xlsx',D_pro_ff,'17_Trafo','C44:FLD61');
xlswrite('M:\Documents\MASTER THESIS\Working_folder\Results_GIS.xlsx',D_pro_ff_2,'17_Trafo','C65:FLD79');

% Matlab script end